# Instructions:

## Install
```
pip install functions-by-nizamimeydan
```
## Intall older versions
```
pip install functions-by-nizamimeydan=VERSION_NUMBER
```

## Operations:
 multiplication(NUMBER1,NUMBER2)

 division(NUMBER1,NUMBER2)

 addition(NUMBER1,NUMBER2)

 substraction(NUMBER1,NUMBER2)


 returns results

 ## Example:

 print(multiplication(67,45))